@@ -77,6 +77,8 @@
 //----------------------------------------------------------------------------
 
 #include <qregexp.h>
+#include <qdesktopwidget.h>
+#include <qapplication.h>
 
 //----------------------------------------------------------------------------
 
@@ -88,9 +90,10 @@
 const char CvsConfig::Version[]                 = "/crossvc/Version";
 const char CvsConfig::Debug[]                   = "/crossvc/Debug";
 const char CvsConfig::LogLevel[]                = "/crossvc/LogLevel";
-const char CvsConfig::CheckStatusIntervall[]	= "/crossvc/Timer/checkStatusIntervall";
+const char CvsConfig::VeryFirstStart[]          = "/crossvc/VeryFirstStart";
+const char CvsConfig::CheckStatusIntervall[]    = "/crossvc/Timer/checkStatusIntervall";
 const char CvsConfig::CheckStatusLevel[]        = "/crossvc/Timer/checkStatusLevel";
-const char CvsConfig::ProgressIntervall[]	= "/crossvc/Timer/progressIntervall";
+const char CvsConfig::ProgressIntervall[]       = "/crossvc/Timer/progressIntervall";
 
 const char CvsConfig::AutoUpdate[]              = "/crossvc/AutoUpdate/Enabled";
 const char CvsConfig::AutoUpdateIntervall[]     = "/crossvc/AutoUpdate/Intervall";
@@ -102,8 +105,8 @@ const char CvsConfig::useDirWatch[]             = "/crossvc/useDirWatch";
 
 const char CvsConfig::SshKeyList[]              = "/crossvc/SshKeyList";
 const char CvsConfig::SshAgent[]                = "/crossvc/SshAgent";
-const char CvsConfig::RemoteBrowser[]		= "/crossvc/remoteBrowser";
-const char CvsConfig::LocalBrowser[]	        = "/crossvc/localBrowser";
+const char CvsConfig::RemoteBrowser[]           = "/crossvc/remoteBrowser";
+const char CvsConfig::LocalBrowser[]            = "/crossvc/localBrowser";
 const char CvsConfig::CVSRsh[]                  = "/crossvc/cvsRsh";
 const char CvsConfig::LocalShell[]              = "/crossvc/localShell";
 const char CvsConfig::DirPopupMenu[]            = "/crossvc/dirPopupMenu";
@@ -121,13 +124,13 @@ const char CvsConfig::HistSizeComments[]        = "/crossvc/historySizeComments"
 const char CvsConfig::HistSizeWorkdirs[]        = "/crossvc/historySizeWorkdirs";
 const char CvsConfig::HistSizeProfiles[]        = "/crossvc/historySizeProfiles";
 
-const char CvsConfig::GeomX[]			= "/crossvc/Geometry/geomX";
-const char CvsConfig::GeomY[]			= "/crossvc/Geometry/geomY";
-const char CvsConfig::GeomWidth[]		= "/crossvc/Geometry/geomWidth";
-const char CvsConfig::GeomHeight[]		= "/crossvc/Geometry/geomHeight";
-const char CvsConfig::SplitterPosH[]		= "/crossvc/Geometry/splitterPosH";
-const char CvsConfig::SplitterPosV[]		= "/crossvc/Geometry/splitterPosV";
-const char CvsConfig::WorkbenchColumnWidth[]	= "/crossvc/Geometry/workbenchColumnWidth";
+const char CvsConfig::GeomX[]                   = "/crossvc/Geometry/geomX";
+const char CvsConfig::GeomY[]                   = "/crossvc/Geometry/geomY";
+const char CvsConfig::GeomWidth[]               = "/crossvc/Geometry/geomWidth";
+const char CvsConfig::GeomHeight[]              = "/crossvc/Geometry/geomHeight";
+const char CvsConfig::SplitterPosH[]            = "/crossvc/Geometry/splitterPosH";
+const char CvsConfig::SplitterPosV[]            = "/crossvc/Geometry/splitterPosV";
+const char CvsConfig::WorkbenchColumnWidth[]    = "/crossvc/Geometry/workbenchColumnWidth";
 const char CvsConfig::ToolbarPos[]              = "/crossvc/Geometry/ToolbarPosition";
 const char CvsConfig::FileHeaderPos[]           = "/crossvc/Geometry/FileHeaderPosition";
 
@@ -140,7 +143,7 @@ const char CvsConfig::DateTimeFormat[]          = "/crossvc/Looknfeel/DateTimeFo
 const char CvsConfig::Use0AsParent[]            = "/crossvc/Looknfeel/use0AsParent";
 const char CvsConfig::TopLevelWidget[]          = "/crossvc/Looknfeel/topLevelWidget";
 
-const char CvsConfig::Compression[]		= "/crossvc/CvsGlobal/compression";
+const char CvsConfig::Compression[]             = "/crossvc/CvsGlobal/compression";
 const char CvsConfig::RwPermission[]            = "/crossvc/CvsGlobal/RwPermission";
 const char CvsConfig::VirtualInFiletab[]        = "/crossvc/CvsGlobal/virtualInFileTab";
 const char CvsConfig::DiffPrecision[]           = "/crossvc/CvsGlobal/diffPrecision";
@@ -200,8 +203,8 @@ const char CvsConfig::TextDecoder[]             = "/crossvc/I18n/TextDecoder";
 const char CvsConfig::defCvsPath[]              = "ocvs";
 const char CvsConfig::defCvsVersion[]           = "cvs";
 const char CvsConfig::defSshAgent[]             = "start-ssh-agent.sh\n%n";
-const char CvsConfig::defRemoteBrowser[]	= "open";
-const char CvsConfig::defLocalBrowser[]		= "open";
+const char CvsConfig::defRemoteBrowser[]        = "open";
+const char CvsConfig::defLocalBrowser[]         = "open";
 const char CvsConfig::defOpenFileList[]         = "*\nopen\n%n\n-";
 const char CvsConfig::defViewFileList[]         = "*\nopen\n%n\n-";
 const char CvsConfig::defLocalShell[]           = "/Applications/Utilities/Terminal";
@@ -210,8 +213,8 @@ const char CvsConfig::defLocalShell[]           = "/Applications/Utilities/Termi
 const char CvsConfig::defCvsPath[]              = "cvs";
 const char CvsConfig::defCvsVersion[]           = "cvs";
 const char CvsConfig::defSshAgent[]             = "start-ssh-agent.sh\n%n";
-const char CvsConfig::defRemoteBrowser[]	= "mozilla";
-const char CvsConfig::defLocalBrowser[]		= "mozilla";
+const char CvsConfig::defRemoteBrowser[]        = "mozilla";
+const char CvsConfig::defLocalBrowser[]         = "mozilla";
 const char CvsConfig::defOpenFileList[]         = "*\nxterm\n-e vi %1\n-";
 const char CvsConfig::defViewFileList[]         = "*\nxterm\n-e more %1\n-";
 const char CvsConfig::defLocalShell[]           = "xterm";
@@ -220,8 +223,8 @@ const char CvsConfig::defLocalShell[]           = "xterm";
 const char CvsConfig::defCvsPath[]              = "cvs";
 const char CvsConfig::defCvsVersion[]           = "cvs";
 const char CvsConfig::defSshAgent[]             = "";
-const char CvsConfig::defRemoteBrowser[]	= "";
-const char CvsConfig::defLocalBrowser[]		= "";
+const char CvsConfig::defRemoteBrowser[]        = "";
+const char CvsConfig::defLocalBrowser[]         = "";
 const char CvsConfig::defOpenFileList[]         = "";
 const char CvsConfig::defViewFileList[]         = "";
 const char CvsConfig::defLocalShell[]           = "";
@@ -232,9 +235,9 @@ const char CvsConfig::defCvsRsh[]               = "ssh";
 const char CvsConfig::defCvsIgnoreFiles[]       = "RCS SCCS CVS CVS.adm RCSLOG cvslog.* tags TAGS .make.state .nse.depinfo *~ #* .#* ,* _$* *$ *.old *.bak *.BAK *.orig *.rej .del-* *.a *.olb *.o *.obj *.so *.exe *.Z *.elc *.ln core";
 
 #ifdef Q_WS_MAC
-const char CvsConfig::defKeyboarsShortcuts[]     = "4,12582980:7,8388677:8,4194373:10,4194392:11,4194376:12,12582984:15,8388684:16,4194384:18,8388689:25,4194386:29,4194388:30,8388692:33,4194389:34,8388693:46,12582991:47,4194370:48,4194387:54,4194371:55,8388694:59,4194372:83,4194385:";
+const char CvsConfig::defKeyboarsShortcuts[]    = "4,12582980:7,8388677:8,4194373:10,4194392:11,4194376:12,12582984:15,8388684:16,4194384:18,8388689:25,4194386:29,4194388:30,8388692:33,4194389:34,8388693:46,12582991:47,4194370:48,4194387:54,4194371:55,8388694:59,4194372:83,4194385:";
 #else
-const char CvsConfig::defKeyboarsShortcuts[]     = "4,12582980:7,8388677:8,4194373:10,4194392:11,4194376:12,12582984:15,8388684:16,4194384:18,8388689:25,4194386:29,4194388:30,8388692:33,4194389:34,8388693:46,12582991:47,4194370:48,4194387:54,4194371:55,8388694:59,4194372:62,4194385:";
+const char CvsConfig::defKeyboarsShortcuts[]    = "4,12582980:7,8388677:8,4194373:10,4194392:11,4194376:12,12582984:15,8388684:16,4194384:18,8388689:25,4194386:29,4194388:30,8388692:33,4194389:34,8388693:46,12582991:47,4194370:48,4194387:54,4194371:55,8388694:59,4194372:62,4194385:";
 #endif
 
 //----------------------------------------------------------------------------
@@ -280,6 +283,8 @@ void CvsConfig::readCfg()
    Mapping::openFileAppList = extractMapping(getOpenFileList());
    Mapping::viewFileAppList = extractMapping(getViewFileList());
    
+   Misc::g_bVeryFirstStart = getVeryFirstStart(Misc::g_bVeryFirstStart);
+
    if (bOVERRIDEONTHEFLYSCANNING) {//startup option
       ONTHEFLYSCANNING = true;
    } else {
@@ -332,6 +337,17 @@ void CvsConfig::readCfg()
    GEOM_WIDTH        = geom.width();
    GEOM_HEIGHT       = geom.height();
    
+   QRect desk = QApplication::desktop()->screenGeometry();
+   if (GEOM_WIDTH > desk.width())   GEOM_WIDTH  = desk.width();
+   if (GEOM_HEIGHT > desk.height()) GEOM_HEIGHT = desk.height();
+   
+   int geomRight = GEOM_X + GEOM_WIDTH;
+   if (geomRight > desk.width()) GEOM_X -= (geomRight - desk.width());
+   if (GEOM_X < 0) GEOM_X = 0;
+   int geomBottom = GEOM_Y + GEOM_HEIGHT;
+   if (geomBottom > desk.height()) GEOM_Y -= (geomBottom - desk.height());
+   if (GEOM_Y < 0) GEOM_Y = 0;
+
    SPLITTER_POS_H    = splitterPosH();
    SPLITTER_POS_V    = splitterPosV();
    WORKBENCH_COLUMN_WIDTH           = workbenchColumnWidth();
@@ -440,6 +456,8 @@ void CvsConfig::writeCfg()
    setOpenFileList(joinMapping(Mapping::openFileAppList));
    setViewFileList(joinMapping(Mapping::viewFileAppList));
    
+   setVeryFirstStart(Misc::g_bVeryFirstStart);
+   
    if (!bOVERRIDEONTHEFLYSCANNING) {//startup option
       setOnTheFlyScanning(ONTHEFLYSCANNING);
    }
@@ -670,14 +688,14 @@ void CvsConfig::removeProjectSettings( QString key) {
 * set to true here.
 */
 void CvsConfig::updateVersionOnRead( const QString& oldVersion, const QString& newVersion) {
-   
-   qDebug(QObject::tr("Detected old LinCVS resource file")
-   +",\n"
-   + QObject::tr("updating from LinCVS version: ")
-   +QString(oldVersion.isEmpty() ? QObject::tr("unknown") : oldVersion)
-   +"\n"
-   +QObject::tr("to new version: ")+newVersion);
-   
+
+   qDebug(QObject::tr("Detected old CrossVC resource file")
+	 +",\n"
+	 + QObject::tr("updating from CrossVC version: ")
+	 +QString(oldVersion.isEmpty() ? QObject::tr("unknown") : oldVersion)
+	 +"\n"
+	 +QObject::tr("to new version: ")+newVersion);
+
    m_needUpdate = FALSE;
    bool updated = FALSE;
    
