@@ -135,9 +135,11 @@ CheckoutDialogImpl::CheckoutDialogImpl( QString dlgCaption,
    m_AccessDict.insert(tr("Password"),&PSERVER);
    m_AccessDict.insert(tr("Remote Shell"),&RSH);
    m_AccessDict.insert(tr("Local/NFS"),&LOCAL);
+   m_AccessDict.insert(tr("SSPI"),&SSPI);
    m_AccessList.append(tr("Password"));
    m_AccessList.append(tr("Remote Shell"));
    m_AccessList.append(tr("Local/NFS"));
+   m_AccessList.append(tr("SSPI"));
 
    m_ProfileList.sort();
    m_ProfileList.prepend(tr("No profile selected"));
@@ -175,14 +177,16 @@ CheckoutDialogImpl::CheckoutDialogImpl( QString dlgCaption,
          m_AccessBox->setCurrentItem(2);
       } else if (connectMethod.startsWith("pserver")) {
          m_AccessBox->setCurrentItem(0);
+      } else if (connectMethod.startsWith("sspi")) {
+         m_AccessBox->setCurrentItem(3);
       } else {
-         m_AccessBox->setCurrentItem(1);
+         m_AccessBox->setCurrentItem(3);
       }
    } else {
       m_UserBox->setCurrentText("");
       m_ServerBox->setCurrentText("");
       m_RepositoryBox->setCurrentText("");
-      m_AccessBox->setCurrentItem(2);
+      m_AccessBox->setCurrentItem(3);
    }
 
    m_SshPresetList.append(tr("no ssh"));
@@ -368,6 +372,8 @@ void CheckoutDialogImpl::browseModulesClicked() {
             } else {
                connMethod = "server";
             }
+         } else if((*m_AccessDict.find(m_AccessBox->currentText()))==SSPI) {
+            connMethod = "sspi";
          }
          
          QString dir = "";
