@@ -79,6 +79,7 @@
 #include <qpushbutton.h>
 #include <qcombobox.h>
 #include <qradiobutton.h>
+#include <qcheckbox.h>
 #include <qfiledialog.h>
 #include <qregexp.h>
 #include <qtimer.h>
@@ -139,9 +140,11 @@ ImportDialogImpl::ImportDialogImpl( QString* defaultProfile,
    m_AccessDict.insert(tr("Password"),&PSERVER);
    m_AccessDict.insert(tr("Remote Shell"),&RSH);
    m_AccessDict.insert(tr("Local/NFS"),&LOCAL);
+   m_AccessDict.insert(tr("SSPI"),&SSPI);
    m_AccessList.append(tr("Password"));
    m_AccessList.append(tr("Remote Shell"));
    m_AccessList.append(tr("Local/NFS"));
+   m_AccessList.append(tr("SSPI"));
 
    if (m_Vendor.empty()) {
       m_Vendor.append(tr("INITIAL_IMPORT_VENDOR_TAG"));
@@ -186,14 +189,16 @@ ImportDialogImpl::ImportDialogImpl( QString* defaultProfile,
 	 m_AccessBox->setCurrentItem(2);
       } else if (connectMethod.startsWith("pserver")) {
 	 m_AccessBox->setCurrentItem(0);
+      } else if (connectMethod.startsWith("sspi")) {
+         m_AccessBox->setCurrentItem(3);
       } else {
-	 m_AccessBox->setCurrentItem(1);
+	 m_AccessBox->setCurrentItem(3);
       }
    } else {
       m_UserBox->setCurrentText("");
       m_ServerBox->setCurrentText("");
       m_RepositoryBox->setCurrentText("");
-      m_AccessBox->setCurrentItem(2);
+      m_AccessBox->setCurrentItem(3);
    }
 
    m_CommitInfo->setText("");
@@ -391,6 +396,8 @@ void ImportDialogImpl::browseModulesClicked() {
 	    } else {
 	       connMethod = "server";
 	    }
+	 } else if((*m_AccessDict.find(m_AccessBox->currentText()))==SSPI) {
+            connMethod = "sspi";
 	 }
 
 	 QString dir = "";
@@ -680,6 +687,14 @@ int ImportDialogImpl::rshMode() {
    }
 }
 
+bool ImportDialogImpl::getKeepFTime() {
+	return m_KeepFTime->isChecked();
+}
+
+bool ImportDialogImpl::getCreateDirs() {
+	return m_CreateDirs->isChecked();
+}
+
 void ImportDialogImpl::getAndSetModule() {
    m_BrowseModules->setCurrentText(m_ModuleBrowser->getModule());
    m_ModuleBrowser = NULL;
